.. documentation master file

.. include:: ../README.rst

.. toctree::
    :caption: Getting started
    :hidden:

    install
    quickstart
    overview
    publish
    load
    dependencies
    configuration
    authentication
    caching

.. Warning: then usage of genindex is a hack to get a TOC entry, see
.. https://stackoverflow.com/a/42310803. This might break the usage of sphinx if
.. you want to create something different than HTML output.
.. toctree::
    :caption: API Documentation
    :hidden:

    api
    api-info
    genindex

.. toctree::
    :caption: Development
    :hidden:

    contributing
    changelog
